#!/bin/bash
##configure.inのAC_INIT(jobarranger, x.x.x) Version　変更

rm -rf autom4te.cache

set -a
. ./.env
set +a

aclocal --system-acdir=/usr/share/aclocal
autoconf
autoheader
automake -a